@@ -43,6 +43,8 @@ class Logger(tasking.Tasker):
                  prefix='~/.ioflo/log',
                  keep=0,
                  cyclePeriod=0.0,
+                 fileSize=0,
+                 reuse=False,
                  **kw):
         """
         Initialize instance.
@@ -59,6 +61,11 @@ class Logger(tasking.Tasker):
             keep = int number of log copies in rotation <1> means do not cycle
             cyclePeriod = interval in seconds between log rotations,
                      0.0 or None means do not rotate
+            fileSize = size in bytes  of log file required to peform rotation
+                       Do not rotate is main file is not at least meet file size
+                       0 means always rotate
+            reuse = Make unique time stamped log directory if True otherwise nonunique
+                    useful when rotating
 
 
         Inherited Class Attributes:
@@ -81,8 +88,11 @@ class Logger(tasking.Tasker):
             .flushPeriod = period between flushes
             .prefix = prefix used to create log directory
             .keep = int number of log copies in rotation, < 1 means do cycle
-            .cyclePeriod = nterval in seconds between log rotations,
+            .cyclePeriod = interval in seconds between log rotations,
                      0.0 or None means do not rotate
+            .fileSize = minimum size in bytes of main log file for rotation to occur
+            .reuse = Make unique time stamped log directory if True otherwise nonunique
+                    useful when rotating
 
             .rotateStamp = time logs last rotated
             .flushStamp = time logs last flushed
@@ -99,6 +109,8 @@ class Logger(tasking.Tasker):
         self.cyclePeriod = max(0.0, cyclePeriod)  # ensure >= 0
         if self.keep > 0 and not self.cyclePeriod:
             self.keep = 0  # cyclePeriod must be nonzero if keep > 0
+        self.fileSize = max(0, fileSize)
+        self.reuse = True if reuse else False
 
         self.cycleStamp = 0.0
         self.flushStamp = 0.0
@@ -167,7 +179,7 @@ class Logger(tasking.Tasker):
         Cycle (Rotate) all log files
         """
         for log in self.logs:
-            log.cycle()
+            log.cycle(size=self.fileSize)
 
     def prepare(self):
         """
@@ -198,18 +210,27 @@ class Logger(tasking.Tasker):
         """
         path = ''
         try:
-            i = 0
-            while True:  # do until keep trying until different
-                dt = datetime.datetime.now()
-                dirname = "{0}_{1:04d}{2:02d}{3:02d}_{4:02d}{5:02d}{6:02d}_{7:03d}".format(
-                           self.name, dt.year, dt.month, dt.day, dt.hour,
-                           dt.minute, dt.second, dt.microsecond // 1000 + i )
-                path = os.path.join(prefix, self.store.house.name, dirname)
-                path = os.path.abspath(path) #convert to proper absolute path
+            if self.reuse:
+                path = os.path.join(prefix, self.store.house.name, self.name)
+                path = os.path.abspath(path)  # convert to proper absolute path
                 if not os.path.exists(path):
                     os.makedirs(path)
-                    break
-                i +=1
+
+            else:  # unique directory name
+                i = 0
+                while True:  # do until keep trying until different
+
+                    dt = datetime.datetime.now()
+                    dirname = "{0}_{1:04d}{2:02d}{3:02d}_{4:02d}{5:02d}{6:02d}_{7:03d}".format(
+                               self.name, dt.year, dt.month, dt.day, dt.hour,
+                               dt.minute, dt.second, dt.microsecond // 1000 + i )
+
+                    path = os.path.join(prefix, self.store.house.name, dirname)
+                    path = os.path.abspath(path) #convert to proper absolute path
+                    if not os.path.exists(path):
+                        os.makedirs(path)
+                        break
+                    i +=1
 
         except OSError as ex:
             console.terse("Error: creating log directory '{0}'\n".format(ex))
@@ -266,6 +287,8 @@ class Logger(tasking.Tasker):
                     if self.status != STOPPED:
                         console.terse("     Stopping Logger {0} ...\n".format(self.name))
                         self.log() #final log
+                        if self.keep and self.reuse:  # recycle in case multiple restarts
+                            self.cycle()  # cause log file to exceed size before cycle time
                         self.close()
                         self.desire = STOP
                         self.status = STOPPED
@@ -338,7 +361,8 @@ class Log(registering.StoriedRegistrar):
 
         super(Log,self).__init__(**kw) #store and name inited here
 
-        self.stamp = None #time stamp last logged, None means never logged
+        self.stamp = None  # time stamp last logged, None means not yet logged
+        self.first = True  # True means file created for the first time
 
         self.kind = kind
         if baseFilename:
@@ -418,6 +442,9 @@ class Log(registering.StoriedRegistrar):
             self.paths = []  # remove stale rotate paths
 
         self.close()  #innocuous to call close() on unopened file
+        if os.path.exists(self.path):
+            self.first = False
+
         try:
             self.file = ocfn(self.path, 'a+')  # append pick up where left off
         except IOError as ex:
@@ -436,7 +463,7 @@ class Log(registering.StoriedRegistrar):
                 self.paths.append(path)
 
                 try:  # trial open file to make
-                    file = ocfn(path, 'w+')  #
+                    file = ocfn(path, 'r')  # do not truncate in case reusing
                 except IOError as ex:
                     console.terse("Error: Creating/opening log rotate file '{0}'\n".format(ex))
                     return False
@@ -462,12 +489,21 @@ class Log(registering.StoriedRegistrar):
             self.file.flush()
             os.fsync(self.file.fileno())
 
-    def cycle(self):
+    def cycle(self, size=0):
         """
         Returns True if cycle rotate successful, False otherwise
-        Cycle log files
+        Cycle log files  Only cycle if size > 0 and main log file size >= size
         """
+
         if self.paths:  # non zero rotate copies
+            self.flush()
+            try:
+                if size and os.path.getsize(self.path) < size:
+                    return False
+            except OSError as ex:
+                console.terse("Error: Reading file size '{0}'\n".format(ex))
+                return False
+
             self.close()  # also flushes
             cycled = True
             for k in reversed(range(len(self.paths) - 1)):
@@ -544,7 +580,6 @@ class Log(registering.StoriedRegistrar):
         self.header = cf.getvalue()
         cf.close()
 
-
     def prepare(self):
         """
         Prepare log formats and values
@@ -564,16 +599,17 @@ class Log(registering.StoriedRegistrar):
             if tag in self.fields:
                 if self.fields[tag]:  # at least one field
                     self.fields[tag] = self.fields[tag][:1]  # only one field allowed
+                else:  # use first fields in loggee if present
+                    self.fields[tag] = [loggee.keys()[0]] if loggee else []
             else:  # fields not given use first fields in loggee if present
                 self.fields[tag] = [loggee.keys()[0]] if loggee else []
 
 
         else:  # default fields from loggee
             for tag, loggee in self.loggees.items():
-                if tag not in self.fields:  # if fields not given use all fields in loggee
+                if tag not in self.fields or not self.fields[tag]:  # if fields not given use all fields in loggee
                     self.fields[tag] = [field for field in loggee]
 
-
         #should be different if binary kind
         #build formats
         self.formats.clear()
@@ -612,7 +648,7 @@ class Log(registering.StoriedRegistrar):
 
         self.buildHeader()
 
-        if self.stamp is None: #never logged so log headers
+        if self.stamp is None and self.first:  # never logged so log headers
             self.file.write(self.header)
 
     def format(self, value):
@@ -623,7 +659,7 @@ class Log(registering.StoriedRegistrar):
             return '\t%0.4f'
         elif isinstance(value, bool):
             return '\t%s'
-        elif isinstance(value, int) or isinstance(value, long):
+        elif isinstance(value, int):
             return '\t%d'
         else:
             return '\t%s'
@@ -875,6 +911,5 @@ class Log(registering.StoriedRegistrar):
             if tag in self.loggees: #only add if not already there
                 raise excepting.ResolveError("Duplicate tag", tag, loggee)
             self.loggees[tag] = loggee
-            if fields:
-                self.fields[tag] = fields
+            self.fields[tag] = fields if fields else []  # need tag to preserve order
 
